package com.huimv.admin.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.admin.common.utils.Result;
import com.huimv.admin.common.utils.ResultCode;
import com.huimv.admin.entity.ProtThreshold;
import com.huimv.admin.mapper.ProtThresholdMapper;
import com.huimv.admin.service.IProtThresholdService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 环保阈值 服务实现类
 * </p>
 *
 * @author author
 * @since 2023-02-14
 */
@Service
public class ProtThresholdServiceImpl extends ServiceImpl<ProtThresholdMapper, ProtThreshold> implements IProtThresholdService {

    @Autowired
    private ProtThresholdMapper protThresholdMapper;

    @Override
    public Result list(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String protType = paramsMap.get("protType");
        QueryWrapper<ProtThreshold> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("farm_id", farmId);
        List<ProtThreshold> protThresholdList = protThresholdMapper.selectList(queryWrapper);
        JSONObject jsonObject = new JSONObject();
        if (protThresholdList.size() == 0) {
            jsonObject.put("COD1", 0);
            jsonObject.put("COD2", 0);
            jsonObject.put("PH1", 0);
            jsonObject.put("PH2", 0);
            jsonObject.put("NH3N1", 0);
            jsonObject.put("NH3N2", 0);
            jsonObject.put("TP1", 0);
            jsonObject.put("TP2", 0);
            jsonObject.put("TN1", 0);
            jsonObject.put("TN2", 0);
            jsonObject.put("FLOW1", 0);
            jsonObject.put("FLOW2", 0);
            jsonObject.put("userIds", 0);
        } else {
            QueryWrapper<ProtThreshold> queryWrapper1 = new QueryWrapper<>();
            queryWrapper1.eq("farm_id", farmId).eq("prot_type", protType);
            ProtThreshold protThreshold = protThresholdMapper.selectOne(queryWrapper1);
            jsonObject.put("COD1", protThreshold.getCod1());
            jsonObject.put("COD2", protThreshold.getCod2());
            jsonObject.put("PH1", protThreshold.getPh1());
            jsonObject.put("PH2", protThreshold.getPh2());
            jsonObject.put("NH3N1", protThreshold.getNh3n1());
            jsonObject.put("NH3N2", protThreshold.getNh3n2());
            jsonObject.put("TP1", protThreshold.getTp1());
            jsonObject.put("TP2", protThreshold.getTp2());
            jsonObject.put("TN1", protThreshold.getTn1());
            jsonObject.put("TN2", protThreshold.getTn2());
            jsonObject.put("FLOW1", protThreshold.getFlow1());
            jsonObject.put("FLOW2", protThreshold.getFlow2());
            jsonObject.put("userIds", protThreshold.getUserIds());
        }
        return new Result(ResultCode.SUCCESS, jsonObject);
    }

    @Override
    public Result add(HttpServletRequest httpServletRequest, Map<String, String> paramsMap) {
        String farmId = paramsMap.get("farmId");
        String protType = paramsMap.get("protType");
        String COD1 = paramsMap.get("COD1");
        String COD2 = paramsMap.get("COD2");
        String PH1 = paramsMap.get("PH1");
        String PH2 = paramsMap.get("PH2");
        String NH3N1 = paramsMap.get("NH3N1");
        String NH3N2 = paramsMap.get("NH3N2");
        String TP1 = paramsMap.get("TP1");
        String TP2 = paramsMap.get("TP2");
        String TN1 = paramsMap.get("TN1");
        String TN2 = paramsMap.get("TN2");
        String FLOW1 = paramsMap.get("FLOW1");
        String FLOW2 = paramsMap.get("FLOW2");
        String userIds = paramsMap.get("userIds");

        ProtThreshold protThreshold = new ProtThreshold();
        protThreshold.setCod1(COD1);
        protThreshold.setCod2(COD2);
        protThreshold.setPh1(PH1);
        protThreshold.setPh2(PH2);
        protThreshold.setNh3n1(NH3N1);
        protThreshold.setNh3n2(NH3N2);
        protThreshold.setTp1(TP1);
        protThreshold.setTp2(TP2);
        protThreshold.setTn1(TN1);
        protThreshold.setTn2(TN2);
        protThreshold.setFlow1(FLOW1);
        protThreshold.setFlow2(FLOW2);
        protThreshold.setUserIds(userIds);
        protThreshold.setProtType(Integer.parseInt(protType));
        protThreshold.setFarmId(Integer.parseInt(farmId));


        if (Integer.parseInt(COD2) < Integer.parseInt(COD1)) {
            return new Result(ResultCode.FAIL, "红色预警浓度不能低于橙色预警浓度");
        } else if (Integer.parseInt(PH2) < Integer.parseInt(PH1)) {
            return new Result(ResultCode.FAIL, "红色预警浓度不能低于橙色预警浓度");
        } else if (Integer.parseInt(NH3N2) < Integer.parseInt(NH3N1)) {
            return new Result(ResultCode.FAIL, "红色预警浓度不能低于橙色预警浓度");
        } else if (Integer.parseInt(TP2) < Integer.parseInt(TP1)) {
            return new Result(ResultCode.FAIL, "红色预警浓度不能低于橙色预警浓度");
        } else if (Integer.parseInt(TN2) < Integer.parseInt(TN1)) {
            return new Result(ResultCode.FAIL, "红色预警浓度不能低于橙色预警浓度");
        } else if (Integer.parseInt(FLOW2) < Integer.parseInt(FLOW1)) {
            return new Result(ResultCode.FAIL, "红色预警浓度不能低于橙色预警浓度");
        } else {
            QueryWrapper<ProtThreshold> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("farm_id", farmId).eq("prot_type",protType);
            ProtThreshold threshold = protThresholdMapper.selectOne(queryWrapper);
            if (ObjectUtil.isEmpty(threshold)) {
                protThresholdMapper.insert(protThreshold);
                return new Result(ResultCode.SUCCESS, "添加成功");
            } else {
                protThreshold.setId(threshold.getId());
                protThresholdMapper.updateById(protThreshold);
                return new Result(ResultCode.SUCCESS, "修改成功");
            }
        }
    }
}
